<?php
/**
 * AWS regions handler.
 *
 * @see https://docs.aws.amazon.com/general/latest/gr/s3.html
 *
 * @since 2.3.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\AWS;

defined( 'ABSPATH' ) || exit;

/**
 * AWS Regions class.
 */
class Regions {

	/**
	 * AWS regions.
	 *
	 * @var array
	 */
	private static $regions = array();

	/**
	 * Loads the AWS regions.
	 *
	 * @since 2.3.0
	 */
	private static function load_regions() {
		self::$regions = array(
			'us-east-1'      => _x( 'US East (N. Virginia)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'us-east-2'      => _x( 'US East (Ohio)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'us-west-1'      => _x( 'US West (N. California)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'us-west-2'      => _x( 'US West (Oregon)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'af-south-1'     => _x( 'Africa (Cape Town)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-east-1'      => _x( 'Asia Pacific (Hong Kong)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-south-2'     => _x( 'Asia Pacific (Hyderabad)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-southeast-3' => _x( 'Asia Pacific (Jakarta)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-south-1'     => _x( 'Asia Pacific (Mumbai)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-northeast-3' => _x( 'Asia Pacific (Osaka)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-northeast-2' => _x( 'Asia Pacific (Seoul)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-southeast-1' => _x( 'Asia Pacific (Singapore)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-southeast-2' => _x( 'Asia Pacific (Sydney)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ap-northeast-1' => _x( 'Asia Pacific (Tokyo)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'ca-central-1'   => _x( 'Canada (Central)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'cn-north-1'     => _x( 'China (Beijing)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'cn-northwest-1' => _x( 'China (Ningxia)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-central-1'   => _x( 'Europe (Frankfurt)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-west-1'      => _x( 'Europe (Ireland)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-west-2'      => _x( 'Europe (London)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-south-1'     => _x( 'Europe (Milan)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-west-3'      => _x( 'Europe (Paris)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-south-2'     => _x( 'Europe (Spain)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-north-1'     => _x( 'Europe (Stockholm)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'eu-central-2'   => _x( 'Europe (Zurich)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'sa-east-1'      => _x( 'South America (São Paulo)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'me-south-1'     => _x( 'Middle East (Bahrain)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'me-central-1'   => _x( 'Middle East (UAE)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'us-gov-east-1'  => _x( 'AWS GovCloud (US-East)', 'aws region', 'woocommerce-amazon-s3-storage' ),
			'us-gov-west-1'  => _x( 'AWS GovCloud (US-West)', 'aws region', 'woocommerce-amazon-s3-storage' ),
		);
	}

	/**
	 * Gets all AWS regions.
	 *
	 * @since 2.3.0
	 *
	 * @return array
	 */
	public static function get_all() {
		if ( empty( self::$regions ) ) {
			self::load_regions();
		}

		return self::$regions;
	}

	/**
	 * Checks the region exists.
	 *
	 * @since 2.3.0
	 *
	 * @param string $region Region key.
	 * @return bool
	 */
	public static function exists( $region ) {
		$regions = self::get_all();

		return array_key_exists( $region, $regions );
	}
}
