<?php
/**
 * WooCommerce Amazon S3 Storage Admin.
 *
 * @since 2.2.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\Admin;

defined( 'ABSPATH' ) || exit;

use Themesquad\WC_Amazon_S3_Storage\Admin\Meta_Boxes\Product_Data_Meta_Box;
use Themesquad\WC_Amazon_S3_Storage\Utilities\Admin_Utils;

/**
 * Admin class.
 */
class Admin {

	/**
	 * Admin init.
	 *
	 * @since 2.2.0
	 */
	public static function init() {
		add_filter( 'plugin_action_links_' . WC_AMAZON_S3_STORAGE_BASENAME, array( __CLASS__, 'action_links' ) );
		add_filter( 'plugin_row_meta', array( __CLASS__, 'plugin_row_meta' ), 10, 2 );

		Notices::init();
		Product_Data_Meta_Box::init();
	}

	/**
	 * Adds custom links to the plugins page.
	 *
	 * @since 2.2.0
	 *
	 * @param array $links The plugin links.
	 * @return array
	 */
	public static function action_links( $links ) {
		$settings_link = sprintf(
			'<a href="%1$s" aria-label="%2$s">%3$s</a>',
			esc_url( Admin_Utils::get_settings_url() ),
			_x( 'View WooCommerce Amazon S3 Storage settings', 'aria-label: settings link', 'woocommerce-amazon-s3-storage' ),
			_x( 'Settings', 'plugin action link', 'woocommerce-amazon-s3-storage' )
		);

		array_unshift( $links, $settings_link );

		return $links;
	}

	/**
	 * Adds custom links to this plugin on the plugins screen.
	 *
	 * @since 2.2.0
	 *
	 * @param mixed $links Plugin Row Meta.
	 * @param mixed $file  Plugin Base file.
	 * @return array
	 */
	public static function plugin_row_meta( $links, $file ) {
		if ( WC_AMAZON_S3_STORAGE_BASENAME !== $file ) {
			return $links;
		}

		$links['docs'] = sprintf(
			'<a href="%1$s" aria-label="%2$s" target="_blank">%3$s</a>',
			esc_url( 'https://woocommerce.com/document/amazon-s3-storage/' ),
			esc_attr_x( 'View WooCommerce Amazon S3 Storage documentation', 'aria-label: documentation link', 'woocommerce-amazon-s3-storage' ),
			esc_html_x( 'Docs', 'plugin row link', 'woocommerce-amazon-s3-storage' )
		);

		$links['support'] = sprintf(
			'<a href="%1$s" aria-label="%2$s" target="_blank">%3$s</a>',
			esc_url( 'https://woocommerce.com/my-account/create-a-ticket?select=18663' ),
			esc_attr_x( 'Open a support ticket at WooCommerce.com', 'aria-label: support link', 'woocommerce-amazon-s3-storage' ),
			esc_html_x( 'Support', 'plugin row link', 'woocommerce-amazon-s3-storage' )
		);

		return $links;
	}
}
