<?php
/**
 * Meta Box: Product Data.
 *
 * Updates the Product Data meta box.
 *
 * @since 2.4.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\Admin\Meta_Boxes;

use Themesquad\WC_Amazon_S3_Storage\Settings;
use Themesquad\WC_Amazon_S3_Storage\Utilities\Admin_Utils;
use Themesquad\WC_Amazon_S3_Storage\Utilities\Asset_Utils;

defined( 'ABSPATH' ) || exit;

/**
 * Product data meta box class.
 */
class Product_Data_Meta_Box {

	/**
	 * Init.
	 *
	 * @since 2.4.0
	 */
	public static function init() {
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ) );
		add_action( 'admin_footer', array( __CLASS__, 'include_views' ) );
	}

	/**
	 * Gets if we are viewing the 'product' screen.
	 *
	 * @since 2.4.0
	 *
	 * @return bool
	 */
	protected static function is_product_screen() {
		return 'product' === Admin_Utils::get_screen_id();
	}

	/**
	 * Enqueue scripts.
	 *
	 * @since 2.4.0
	 */
	public static function enqueue_scripts() {
		if ( ! self::is_product_screen() ) {
			return;
		}

		wp_enqueue_style( 'wc-s3-storage-admin', Asset_Utils::get_style_url( 'admin' ), array(), WC_AMAZON_S3_STORAGE_VERSION );
		wp_enqueue_script( 'wc-s3-storage-meta-boxes-product', Asset_Utils::get_script_url( 'admin/meta-boxes-product' ), array( 'jquery-tiptip', 'wc-clipboard', 'wc-backbone-modal' ), WC_AMAZON_S3_STORAGE_VERSION, true );
		wp_localize_script(
			'wc-s3-storage-meta-boxes-product',
			'wcS3StorageMetaBoxesProduct',
			array(
				'addFileBtnText' => __( 'Add S3 File', 'woocommerce-amazon-s3-storage' ),
			)
		);
	}

	/**
	 * Adds meta box views.
	 *
	 * @since 2.4.0
	 */
	public static function include_views() {
		if ( ! self::is_product_screen() ) {
			return;
		}

		$args = array(
			'regions' => Admin_Utils::get_region_options(),
			'bucket'  => Settings::get_setting( 'default_bucket', '' ),
		);

		include_once 'views/shortcode-modal.php';
	}
}
