<?php
/**
 * Meta box View: Shortcode modal.
 *
 * @since 2.4.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Template vars.
 *
 * @var array $args {
 *     Template arguments.
 *
 *     @type string $bucket  Default bucket name.
 *     @type array  $regions An array with the S3 Region options.
 * }
 */
?>
<script type="text/html" id="tmpl-wc-amazon-s3-storage-shortcode-modal">
	<div class="wc-backbone-modal wc-amazon-s3-storage-shortcode-modal">
		<div class="wc-backbone-modal-content">
			<section class="wc-backbone-modal-main" role="main">
				<header class="wc-backbone-modal-header">
					<h1>
						<# if ( data.action === 'edit' ) { #>
							<?php esc_html_e( 'Edit S3 File', 'woocommerce-amazon-s3-storage' ); ?>
						<# } else { #>
							<?php esc_html_e( 'Add S3 File', 'woocommerce-amazon-s3-storage' ); ?>
						<# } #>
					</h1>

					<button class="modal-close modal-close-link dashicons dashicons-no-alt">
						<span class="screen-reader-text"><?php esc_html_e( 'Close modal panel', 'woocommerce' ); // phpcs:ignore WordPress.WP.I18n.TextDomainMismatch ?></span>
					</button>
				</header>
				<article>
					<div class="shortcode-container">
						<span class="shortcode-text"></span>
					</div>

					<form class="shortcode-form" method="post" action="#">
						<div class="panel woocommerce_options_panel">
							<div class="options_group">
								<?php
								woocommerce_wp_text_input(
									array(
										'id'          => 'bucket',
										'label'       => __( 'Bucket Name', 'woocommerce-amazon-s3-storage' ),
										'description' => __( 'Leave this field empty to use the default bucket.', 'woocommerce-amazon-s3-storage' ),
										'value'       => '{{ data.shortcode.bucket }}',
										'placeholder' => $args['bucket'],
									)
								);

								woocommerce_wp_select(
									array(
										'id'          => 'region',
										'label'       => __( 'S3 Region', 'woocommerce-amazon-s3-storage' ),
										'class'       => 'select wc-enhanced-select',
										'description' => __( 'Select the S3 region to use.', 'woocommerce-amazon-s3-storage' ),
										'options'     => array( '' => __( 'Default', 'woocommerce-amazon-s3-storage' ) ) + $args['regions'],
									)
								);

								woocommerce_wp_text_input(
									array(
										'id'          => 'object',
										'label'       => __( 'Object', 'woocommerce-amazon-s3-storage' ),
										'value'       => '{{ data.shortcode.object }}',
										'description' => __( 'Relative path to the S3 object.', 'woocommerce-amazon-s3-storage' ),
										'placeholder' => _x( 'path/filename.ext', 'shortcode object param placeholder', 'woocommerce-amazon-s3-storage' ),
										'custom_attributes' => array(
											'required' => 'required',
										),
									)
								);
								?>
							</div>
						</div>

						<input class="screen-reader-text" type="submit" name="submit" />
					</form>
				</article>
				<footer>
					<div class="inner">
						<div class="wc-action-button-group">
							<span class="wc-action-button-group__items">
								<?php
								printf(
									'<a class="button button-secondary button-large copy-shortcode" href="#" data-tip="%1$s">%2$s</a>',
									esc_attr__( 'Copied!', 'woocommerce-amazon-s3-storage' ),
									esc_html__( 'Copy shortcode', 'woocommerce-amazon-s3-storage' )
								);
								?>
							</span>
						</div>

						<a class="button button-primary button-large add-file" href="#">
							<# if ( data.action === 'edit' ) { #>
								<?php esc_html_e( 'Update file', 'woocommerce-amazon-s3-storage' ); ?>
							<# } else { #>
								<?php esc_html_e( 'Add file', 'woocommerce-amazon-s3-storage' ); ?>
							<# } #>
						</a>
					</div>
				</footer>
			</section>
		</div>
	</div>
	<div class="wc-backbone-modal-backdrop modal-close"></div>
</script>
