<?php
/**
 * Update: Migrate product files v2.0.0.
 *
 * @since 2.5.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\Database\Updates;

defined( 'ABSPATH' ) || exit;

use Themesquad\WC_Amazon_S3_Storage\Internal\Abstracts\Update;

/**
 * Class Update_200_Migrate_Product_Files.
 */
class Update_200_Migrate_Product_Files extends Update {

	/**
	 * Runs the update.
	 *
	 * @since 2.5.0
	 *
	 * @return false
	 */
	public function run() {
		$product_types   = array_keys( wc_get_product_types() );
		$product_types[] = 'variation';

		$product_ids = wc_get_products(
			array(
				'type'     => $product_types,
				'limit'    => - 1,
				'return'   => 'ids',
				'meta_key' => '_amazon_s3_bucket', // phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
			)
		);

		foreach ( $product_ids as $product_id ) {
			$product = wc_get_product( $product_id );

			if ( ! $product || 'yes' !== $product->get_meta( '_use_amazon_s3' ) ) {
				continue;
			}

			$bucket = $product->get_meta( '_amazon_s3_bucket' );
			$object = $product->get_meta( '_amazon_s3_object' );

			$shortcode = sprintf( '[amazon_s3 bucket=%1$s object=%2$s]', $bucket, $object );

			$download = new \WC_Product_Download();
			$download->set_id( wp_generate_uuid4() );
			$download->set_name( wc_get_filename_from_url( $object ) );
			$download->set_file( $shortcode );

			$downloads   = $product->get_downloads();
			$downloads[] = $download;

			try {
				$product->set_downloads( $downloads );
			} catch ( \WC_Data_Exception $e ) {
				continue;
			}

			$product->delete_meta_data( '_use_amazon_s3' );
			$product->delete_meta_data( '_amazon_s3_bucket' );
			$product->delete_meta_data( '_amazon_s3_object' );
			$product->save();
		}

		return false;
	}
}
