<?php
/**
 * Update: DB Version.
 *
 * @since 2.5.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\Database\Updates;

defined( 'ABSPATH' ) || exit;

use Themesquad\WC_Amazon_S3_Storage\Database\Installer;
use Themesquad\WC_Amazon_S3_Storage\Internal\Abstracts\Update;

/**
 * Class Update_DB_Version.
 */
class Update_DB_Version extends Update {

	/**
	 * Constructor.
	 *
	 * @since 2.5.0
	 *
	 * @param array $args Update args.
	 */
	public function __construct( $args = array() ) {
		$args = wp_parse_args(
			$args,
			array(
				'version' => WC_AMAZON_S3_STORAGE_VERSION,
			)
		);

		parent::__construct( $args );
	}

	/**
	 * Generates the update ID.
	 *
	 * @since 2.5.0
	 *
	 * @return string
	 */
	protected function generate_id() {
		return sprintf(
			'update_%d_db_version',
			str_replace( '.', '', sanitize_text_field( $this->args['version'] ) )
		);
	}

	/**
	 * Runs the update.
	 *
	 * @since 2.5.0
	 *
	 * @return false
	 */
	public function run() {
		Installer::update_version( $this->args['version'], 'db' );

		return false;
	}
}
