<?php
/**
 * Handles the plugin privacy policy.
 *
 * @since 2.5.0
 */

namespace Themesquad\WC_Amazon_S3_Storage;

/**
 * Privacy class.
 */
class Privacy extends \WC_Abstract_Privacy {

	/**
	 * Constructor.
	 *
	 * @since 2.5.0
	 */
	public function __construct() {
		parent::__construct( __( 'WooCommerce Amazon S3 Storage', 'woocommerce-amazon-s3-storage' ) );
	}

	/**
	 * Gets the content for the privacy policy page.
	 *
	 * @since 2.5.0
	 */
	public function get_privacy_message() {
		ob_start();
		?>
		<div contenteditable="false">
			<p class="wp-policy-help">
				<?php esc_html_e( 'By using WooCommerce Amazon S3 Storage, you may be storing personal data or sharing data with an external service. Depending on what settings are enabled the specific information shared by your store will vary. ', 'woocommerce-amazon-s3-storage' ); ?>
			</p>
		</div>
		<h2><?php esc_html_e( 'What we collect and store', 'woocommerce-amazon-s3-storage' ); ?></h2>
		<p><?php esc_html_e( 'This extension does not collect or store any information about the customers.', 'woocommerce-amazon-s3-storage' ); ?></p>
		<h2><?php esc_html_e( 'What we share with others', 'woocommerce-amazon-s3-storage' ); ?></h2>
		<p><?php esc_html_e( 'When customers click on a link generated by this extension to download a file stored in the AWS S3 service, this one may collect personal data like:', 'woocommerce-amazon-s3-storage' ); ?></p>
		<ul>
			<li><?php esc_html_e( 'The Internet protocol (IP) address.', 'woocommerce-amazon-s3-storage' ); ?></li>
			<li><?php esc_html_e( 'The location of the device or computer.', 'woocommerce-amazon-s3-storage' ); ?></li>
			<li><?php esc_html_e( 'The computer and device information.', 'woocommerce-amazon-s3-storage' ); ?></li>
		</ul>
		<p>
			<?php
			echo wp_kses_post(
				sprintf(
					/* translators: %s: AWS privacy policy URL */
					__( 'Please, visit the <a target="_blank" href="%s">AWS Privacy Policy</a> page for more details.', 'woocommerce-amazon-s3-storage' ),
					esc_url( 'https://aws.amazon.com/privacy/' )
				)
			);
			?>
		</p>
		<?php

		/**
		 * Filters the privacy policy content.
		 *
		 * @since 2.5.0
		 *
		 * @param string $content The privacy policy content.
		 */
		return apply_filters( 'wc_amazon_s3_storage_privacy_policy_content', ob_get_clean() );
	}

}
