<?php
/**
 * Admin utilities.
 *
 * @since 2.4.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\Utilities;

use Themesquad\WC_Amazon_S3_Storage\AWS\Regions;

/**
 * Class Admin_Utils.
 */
class Admin_Utils {

	/**
	 * Gets the current screen ID.
	 *
	 * @since 2.4.0
	 *
	 * @return string|false The screen ID. False otherwise.
	 */
	public static function get_screen_id() {
		$screen_id = false;

		// It may not be available.
		if ( function_exists( 'get_current_screen' ) ) {
			$screen    = get_current_screen();
			$screen_id = isset( $screen, $screen->id ) ? $screen->id : false;
		}

		// Get the value from the request.
		if ( ! $screen_id && ! empty( $_REQUEST['screen'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification
			$screen_id = wc_clean( wp_unslash( $_REQUEST['screen'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
		}

		return $screen_id;
	}

	/**
	 * Gets the settings page URL.
	 *
	 * @since 2.5.0
	 *
	 * @return string
	 */
	public static function get_settings_url() {
		return admin_url( 'admin.php?page=wc-settings&tab=integration&section=amazon_s3_storage' );
	}

	/**
	 * Gets the options for the S3 Regions select field.
	 *
	 * @since 2.4.0
	 *
	 * @return array
	 */
	public static function get_region_options() {
		$regions = Regions::get_all();
		$options = array();

		foreach ( $regions as $key => $label ) {
			$options[ $key ] = sprintf( '%1$s | %2$s', $label, $key );
		}

		return $options;
	}
}
