<?php
/**
 * Assets utilities.
 *
 * @since 2.4.0
 */

namespace Themesquad\WC_Amazon_S3_Storage\Utilities;

/**
 * Class Asset_Utils.
 */
class Asset_Utils {

	/**
	 * Gets the suffix for the script filenames.
	 *
	 * @since 2.4.0
	 *
	 * @return string
	 */
	public static function get_script_suffix() {
		return ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min' );
	}

	/**
	 * Gets the URL for the specified script.
	 *
	 * @since 2.4.0
	 *
	 * @param string $script Script relative path.
	 * @return string
	 */
	public static function get_script_url( $script ) {
		return WC_AMAZON_S3_STORAGE_URL . 'assets/js/' . $script . self::get_script_suffix() . '.js';
	}

	/**
	 * Gets the URL for the specified stylesheet.
	 *
	 * @since 2.4.0
	 *
	 * @param string $style Stylesheet relative path.
	 * @return string
	 */
	public static function get_style_url( $style ) {
		return WC_AMAZON_S3_STORAGE_URL . 'assets/css/' . $style . '.css';
	}
}
