<?php
/**
 * WooCommerce Amazon S3 Storage Uninstall
 *
 * Deletes the plugin options.
 *
 * @package WC_Amazon_S3_Storage/Uninstaller
 * @since   2.5.1
 */

defined( 'WP_UNINSTALL_PLUGIN' ) || exit;

/**
 * Plugin uninstall script.
 *
 * @since 2.5.1
 *
 * @global wpdb $wpdb The WordPress Database Access Abstraction Object.
 */
function wc_amazon_s3_uninstall() {
	global $wpdb;

	/*
	 * Only remove ALL the plugin data if WC_REMOVE_ALL_DATA constant is set to true in the wp-config.php file.
	 * This is to prevent data loss when deleting the plugin from the backend
	 * and to ensure only the site owner can perform this action.
	 */
	if ( defined( 'WC_REMOVE_ALL_DATA' ) && true === WC_REMOVE_ALL_DATA ) {
		// Deletes the plugin options.
		$wpdb->query( "DELETE FROM $wpdb->options WHERE option_name LIKE '%amazon_s3_storage%';" );
	} else {
		// Clear credentials.
		$settings = get_option( 'woo_amazon_s3_storage', array() );

		if ( ! empty( $settings ) ) {
			$settings['amazon_access_key']    = '';
			$settings['amazon_access_secret'] = '';

			update_option( 'woo_amazon_s3_storage', $settings );
		}
	}
}
wc_amazon_s3_uninstall();
