<?php
/**
 * Plugin Name: WooCommerce Amazon S3 Storage
 * Plugin URI: https://woocommerce.com/products/amazon-s3-storage/
 * Description: Store your downloadable products on Amazon S3 offering faster downloads for your customers and more security for your product.
 * Version: 2.5.1
 * Author: Themesquad
 * Author URI: https://themesquad.com/
 * Requires PHP: 5.6
 * Requires at least: 4.9
 * Tested up to: 6.2
 * Text Domain: woocommerce-amazon-s3-storage
 * Domain Path: /languages
 *
 * WC requires at least: 3.7
 * WC tested up to: 7.6
 * Woo: 18663:473bf6f221b865eff165c97881b473bb
 *
 * License: GNU General Public License v3.0
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package WC_Amazon_S3_Storage
 */

defined( 'ABSPATH' ) || exit;

// Load the class autoloader.
require __DIR__ . '/src/Autoloader.php';

if ( ! \Themesquad\WC_Amazon_S3_Storage\Autoloader::init() ) {
	return;
}

// Plugin requirements.
\Themesquad\WC_Amazon_S3_Storage\Requirements::init();

if ( ! \Themesquad\WC_Amazon_S3_Storage\Requirements::are_satisfied() ) {
	return;
}

// Define plugin file constant.
if ( ! defined( 'WC_AMAZON_S3_STORAGE_FILE' ) ) {
	define( 'WC_AMAZON_S3_STORAGE_FILE', __FILE__ );
}

/**
 * Initialize plugin.
 */
function wc_amazon_s3_init() {
	/**
	 * WooCommerce_Amazon_S3_Storage class
	 */
	if ( ! class_exists( 'WooCommerce_Amazon_S3_Storage' ) ) {

		class WooCommerce_Amazon_S3_Storage extends \Themesquad\WC_Amazon_S3_Storage\Plugin {

			/**
			 * Constructor.
			 */
			protected function __construct() {
				parent::__construct();

				// Create Menu under WooCommerce Menu
				add_action( 'admin_menu', array( $this, 'register_menu' ) );
				add_filter( 'woocommerce_downloadable_product_name', array( $this, 'wc2_product_download_name' ), 10, 4 );
				add_filter( 'woocommerce_file_download_path', array( $this, 'wc2_product_download' ), 1, 3 );

				// Add amazon_s3 shortcode
				add_shortcode( 'amazon_s3', array( $this, 'amazon_shortcode' ) );
			}

			/**
			 * Autoload in-accessible properties on demand.
			 *
			 * Keep backward compatibility with some deprecated properties on this class.
			 *
			 * @since 2.2.0
			 *
			 * @param mixed $key Key name.
			 * @return mixed
			 */
			public function __get( $key ) {
				switch ( $key ) {
					case 'disable_ssl':
						wc_doing_it_wrong( 'WooCommerce_Amazon_S3_Storage->disable_ssl', 'This property is deprecated and will be removed in future releases.', '2.2.0' );
						return 0;
					case 'settings_name':
						wc_doing_it_wrong( 'WooCommerce_Amazon_S3_Storage->settings_name', 'This property is deprecated and will be removed in future releases.', '2.2.0' );
						return 'woo_amazon_s3_storage';
					case 'credentials':
						wc_doing_it_wrong( 'WooCommerce_Amazon_S3_Storage->credentials', 'This property is deprecated and will be removed in future releases.', '2.5.1' );
						$settings = $this->get_settings();

						return array(
							'key'    => $settings['amazon_access_key'],
							'secret' => $settings['amazon_access_secret'],
						);
				}
			}

			/**
			 * Includes the necessary files.
			 *
			 * @deprecated 2.5.0
			 */
			public function includes() {
				wc_deprecated_function( __FUNCTION__, '2.5.0' );
			}

			/**
			 * Expires region transients.
			 *
			 * @since 2.1.5
			 * @deprecated 2.5.0
			 */
			public function temp_upgrade() {
				wc_deprecated_function( __FUNCTION__, '2.5.0', '\Themesquad\WC_Amazon_S3_Storage\Database\Updates\Update_215_Expire_Region_Transients->run()' );

				$version = \Themesquad\WC_Amazon_S3_Storage\Database\Installer::get_version();

				if ( empty( $version ) || version_compare( $version, '2.1.5', '<' ) ) {
					$update = new \Themesquad\WC_Amazon_S3_Storage\Database\Updates\Update_215_Expire_Region_Transients();
					$update->run();
				}
			}

			/**
			 * Add custom plugin action links.
			 *
			 * @since 2.1.8
			 * @deprecated 2.2.0
			 *
			 * @param array $links Links.
			 * @return array
			 */
			public function plugin_action_links( $links ) {
				wc_deprecated_function( __FUNCTION__, '2.2.0' );

				return $links;
			}

			function register_menu() {
				add_submenu_page( 'woocommerce', __( 'WooCommerce Amazon S3 Storage', 'woocommerce-amazon-s3-storage' ), __( 'Amazon S3 Storage', 'woocommerce-amazon-s3-storage' ), 'manage_woocommerce', 'admin.php?page=wc-settings&tab=integration&section=amazon_s3_storage' );
			}

			/**
			 * Plugin update.
			 *
			 * @since 2.0.0
			 * @deprecated 2.5.0
			 */
			public function upgrade() {
				wc_deprecated_function( __FUNCTION__, '2.5.0', '\Themesquad\WC_Amazon_S3_Storage\Database\Updates\Update_200_Migrate_Product_Files->run()' );

				$update = new \Themesquad\WC_Amazon_S3_Storage\Database\Updates\Update_200_Migrate_Product_Files();
				$update->run();
			}

			/**
			 * @deprecated 2.5.0
			 */
			function array_to_options( $array, $selected, $escape = '' ) {
				wc_deprecated_function( __FUNCTION__, '2.5.0' );

				$options = '';
				foreach ( $array as $id => $value ) {
					$options .= '<option value="' . esc_attr( $id ) . '" ' . selected( $array, $selected ) . '>' . esc_attr( $value ) . '</option>';
				}
				return $options . $escape;
			}

			/**
			 * Old settings page.
			 *
			 * @deprecated 2.2.0
			 */
			public function menu_setup() {
				wc_deprecated_function( __FUNCTION__, '2.2.0' );
			}

			public function wc2_product_download( $file_path, $product_id, $download_id ) {
				// Only run do_shortcode when it is a shortcode and on the front-end, or when it is REST only for GET and context != edit
				$is_shortcode = '[' === substr( $file_path, 0, 1 ) && ']' === substr( $file_path, -1 );
				$is_rest      = defined( 'REST_REQUEST' );

				if ( $is_shortcode && (
					( ! $is_rest && ! is_admin() ) ||
					( $is_rest && 'GET' === strtoupper( $_SERVER['REQUEST_METHOD'] ) &&
						( ! isset( $_GET['context'] ) || 'edit' !== $_GET['context'] ) ) ) ) {
					return do_shortcode( $file_path );
				}

				return $file_path;
			}

			/**
			 * Filters the name so the amazon tag or any of its parts don't show - we just want the file name if possible
			 */
			function wc2_product_download_name( $name, $product, $download_id, $file_number ) {
				if ( strpos( $name, '[amazon_s3' ) === false ) {
					return $name;
				}

				$name = str_replace( '[amazon_s3 ', "[amazon_s3 return='name' ", $name );
				return do_shortcode( $name );
			}

			/**
			 * @deprecated 2.2.0
			 */
			function set_ssl( $amazon_s3_object ) {
				wc_deprecated_function( __FUNCTION__, '2.2.0' );
			}

			/**
			 * Processes the Amazon S3 shortcode.
			 *
			 * @param array $atts Shortcode attributes.
			 * @return string
			 */
			public function amazon_shortcode( $atts ) {
				require_once 'amazon-s3-api.php';

				$settings = $this->get_settings();

				$atts = shortcode_atts(
					array(
						'bucket' => $settings['default_bucket'],
						'region' => '',
						'object' => '',
						'return' => 'url',
					),
					$atts,
					'amazon_s3'
				);

				if ( 'name' === $atts['return'] ) {
					return $atts['object'];
				}

				if ( empty( $atts['bucket'] ) || empty( $atts['object'] ) ) {
					return '';
				}

				/*
				 * Bucket names must be unique across all the AWS Regions within a partition.
				 * So, we use the default region only for the default bucket.
				 *
				 * @see https://docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html
				 */
				if ( $atts['bucket'] === $settings['default_bucket'] && empty( $atts['default_region'] ) ) {
					$atts['region'] = $settings['default_region'];
				}

				$object = str_replace( array( '+', ' ' ), '%20', $atts['object'] );

				$period = ( ! empty( $settings['amazon_url_period'] ) ? absint( $settings['amazon_url_period'] ) : 1 );
				$period = $period * MINUTE_IN_SECONDS;

				$s3 = new AmazonS3(
					array(
						'key'    => $settings['amazon_access_key'],
						'secret' => $settings['amazon_access_secret'],
					)
				);

				$amazon_url = $s3->get_object_url( $atts['bucket'], $object, $period, $atts['region'] );

				if ( empty( $amazon_url ) ) {
					wc_add_notice( __( 'A download failed due to connection problems with Amazon S3, please check your settings.', 'woocommerce-amazon-s3-storage' ), 'error' );
					return '';
				}

				return $amazon_url;
			}

			/**
			 * Gets the plugin settings.
			 *
			 * @since 2.1.23
			 *
			 * @return array
			 */
			public function get_settings() {
				return \Themesquad\WC_Amazon_S3_Storage\Settings::get_settings();
			}
		}
	} // End if().
	global $WooCommerce_Amazon_S3_Storage;
	$WooCommerce_Amazon_S3_Storage = WooCommerce_Amazon_S3_Storage::instance();
}

wc_amazon_s3_init();
